@@ -1,7 +1,7 @@
 package Complete::Module;
 
-our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-10-08'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,14 +22,37 @@ if ($ENV{COMPLETE_MODULE_OPT_SHORTCUT_PREFIXES}) {
         { split /=|;/, $ENV{COMPLETE_MODULE_OPT_SHORTCUT_PREFIXES} };
 } else {
     $OPT_SHORTCUT_PREFIXES = {
+        #cp  => 'Catalyst/Plugin/' # candidate
         df  => 'DateTime/Format/',
+        #dp  => 'Dancer/Plugin/', # candidate
+        #d2p  => 'Dancer2/Plugin/', # candidate
+        dz  => 'Dist/Zilla/',
         dzb => 'Dist/Zilla/PluginBundle/',
         dzp => 'Dist/Zilla/Plugin/',
         dzr => 'Dist/Zilla/Role/',
+        #pa  => 'Plack/App/', # candidate
+        #pc  => 'POE/Component/', # candidate
+        #pc  => 'Perl/Critic/', # candidate?
+        #pcp => 'Perl/Critic/Policy/', # candidate?
+        #pd  => 'Padre/Document/', # candidate
+        #pm  => 'Plack/Middleware/', # candidate
+        #pp  => 'Padre/Plugin/', # candidate
+        pw  => 'Pod/Weaver/',
         pwb => 'Pod/Weaver/PluginBundle/',
         pwp => 'Pod/Weaver/Plugin/',
         pwr => 'Pod/Weaver/Role/',
         pws => 'Pod/Weaver/Section/',
+        #rtx => 'RT/Extension/', # candidate
+        #se  => 'Search/Elasticsearch/', # candidate
+        #sec => 'Search/Elasticsearch/Client/', # candidate
+        #ser => 'Search/Elasticsearch/Role/', # candidate
+        #tp  => 'Template/Plugin/', # candidate
+        #tw  => 'Tickit/Widget/', # candidate
+
+        # MooseX, MooX
+        # Moose::Exception
+        # Finance::Bank
+        # Mojo::*, MojoX::*, Mojolicious::*
     };
 }
 
@@ -86,7 +109,7 @@ _
             schema => 'bool',
         },
         dig_leaf => {
-            summary => 'bool',
+            schema => 'bool',
         },
         find_pm => {
             summary => 'Whether to find .pm files',
@@ -232,7 +255,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.21 of Complete::Module (from Perl distribution Complete-Module), released on 2015-09-23.
+This document describes version 0.22 of Complete::Module (from Perl distribution Complete-Module), released on 2015-10-08.
 
 =head1 SYNOPSIS
 
@@ -248,9 +271,11 @@ Shortcut prefixes. The default is:
 
  {
    df  => "DateTime/Format/",
+   dz  => "Dist/Zilla/",
    dzb => "Dist/Zilla/PluginBundle/",
    dzp => "Dist/Zilla/Plugin/",
    dzr => "Dist/Zilla/Role/",
+   pw  => "Pod/Weaver/",
    pwb => "Pod/Weaver/PluginBundle/",
    pwp => "Pod/Weaver/Plugin/",
    pwr => "Pod/Weaver/Role/",
@@ -293,6 +318,8 @@ recursing; 4) contains conveniences for completion, e.g. map casing, expand
 intermediate paths (see C<Complete> for more details on those features),
 autoselection of path separator character, some shortcuts, and so on.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -301,9 +328,7 @@ Arguments ('*' denotes required arguments):
 
 Whether to do case-insensitive search.
 
-=item * B<dig_leaf> => I<any>
-
-bool.
+=item * B<dig_leaf> => I<bool>
 
 =item * B<exp_im_path> => I<bool>
 
