@@ -5,6 +5,7 @@ use warnings;
 use Complete;
 use Complete::Module qw(complete_module);
 use Complete::Path;
+use Complete::Util qw(arrayify_answer);
 use File::Slurp::Tiny qw(write_file);
 use File::Temp qw(tempdir);
 use Filesys::Cap qw(fs_is_cs);
@@ -12,7 +13,7 @@ use Test::More 0.98;
 
 sub test_complete {
     my %args = @_;
-    my $actual_res = complete_module(%{$args{args}});
+    my $actual_res = arrayify_answer(complete_module(%{$args{args}}));
     is_deeply($actual_res, $args{result}) or diag explain $actual_res;
 }
 
